"""entity classes for task entities

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from datetime import date

from logilab.common.date import date_range

from cubicweb.mixins import TreeMixIn
from cubicweb.entities import AnyEntity, fetch_config
from cubicweb.interfaces import ICalendarViews, ICalendarable

class Event(AnyEntity):
    __regid__ = 'Event'
    __implements__ = (ICalendarViews, ICalendarable)

    fetch_attrs, fetch_order = fetch_config(['title'])

    @property
    def start(self):
        return self.diem

    @property
    def stop(self):
        return self.end_date

    def dc_title(self):
        return self.title

    def matching_dates(self, begin, end):
        """calendar views interface"""
        start = self.diem
        stop = self.end_date
        if not start and not stop:
            return []
        elif start and not stop:
            stop = start+1
        elif stop and not start:
            start = stop-1
        return list(date_range(start, stop))



"""Specific views for events

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from cubicweb.selectors import implements
from cubicweb.web.views.baseviews import TextView

class EventTextView(TextView):
    __select__ = implements('Event')

    def cell_call(self, row, col):
        entity = self.cw_rset.get_entity(row, col)
        self.w(u'%s: %s' % (entity.printable_value('diem'), entity.title))



from cubicweb.selectors import implements
from cubicweb.sobjects.notification import ContentAddedView

class EventAddedView(ContentAddedView):
    """get notified from new events"""
    __select__ = implements('Event')
    content_attr = 'description'



# pylint: disable-msg=W0622
"""cubicweb-event packaging information"""

modname = 'event'
distname = "cubicweb-event"

numversion = (1, 3, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
copyright = '''Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
http://www.logilab.fr/ -- mailto:contact@logilab.fr'''

author = "Logilab"
author_email = "contact@logilab.fr"
web = 'http://www.cubicweb.org/project/%s' % distname

short_desc = "event component for the CubicWeb framework"
long_desc = """This CubicWeb component models events.

CubicWeb is a semantic web application framework, see http://www.cubicweb.org
"""

classifiers = [
    'Environment :: Web Environment',
    'Framework :: CubicWeb',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    ]

__depends_cubes__ = {}
__depends__ = {'cubicweb': '>= 3.6.0'}
__use__ = tuple(__depends_cubes__)

from os import listdir
from os.path import join

CUBES_DIR = join('share', 'cubicweb', 'cubes')
try:
    data_files = [
        [join(CUBES_DIR, 'event'),
         [fname for fname in listdir('.')
          if fname.endswith('.py') and fname != 'setup.py']],
        [join(CUBES_DIR, 'event', 'data'),
         [join('data', fname) for fname in listdir('data')]],
        [join(CUBES_DIR, 'event', 'i18n'),
         [join('i18n', fname) for fname in listdir('i18n')]],
        [join(CUBES_DIR, 'event', 'migration'),
         [join('migration', fname) for fname in listdir('migration')]],
        ]
except OSError:
    # we are in an installed directory
    pass


cube_eid = 20328
